Serena Dashboard

## What's New

Loading news...

## Current Configuration

Loading configuration...

## Tool Usage

Loading stats...

## Executions Queue

Loading executions...

## Last Execution

Loading...

## Cancelled Executions

No cancelled executions.

## Registered Projects ▼

Loading projects...

## Available Tools (Disabled) ▼

Loading tools...

## Available Modes ▼

Loading modes...

## Available Contexts ▼

Loading contexts...
No tool stats collected yet.

### Tool Calls

### Input Tokens

### Output Tokens

### Input vs Output Tokens

×

### Add Language

Adding a language to serena config of project .

Note that this may download some dependencies needed for the language server and then start it, it may take a few seconds before the LS is responsive.

Select Language:
×

Remove language from configuration?

×

### Memory:

×

Delete memory ?

×

Create a new memory for project .

Memory names should be descriptive and use underscores instead of spaces (e.g., "api_architecture", "testing_guidelines"). Use "/" to organize memories into subdirectories (e.g., "architecture/api_design"), use the "global/" prefix to write memories that are shared across projects (e.g., "global/java/style_guide").

Memory Name:
×

Are you sure? The execution will continue running until timeout, it will simply no longer be in the queue. Abandoning a running execution is only advised as a measure for unblocking Serena.

×

### Global Serena Configuration

Note: Changes to the configuration will only take effect after Serena is restarted.